import * as Iceform from '@modal-sh/iceform-next';
import * as React from 'react';

export interface NotesItemPageProps {
	note: {
		id: string;
		title: string;
		content: string;
		image: string;
	}
}

const NotesItemPage: Iceform.NextPage<NotesItemPageProps> = ({
	req,
	res,
	note,
}) => {
	const body = (res.body ?? note ?? {}) as Record<string, unknown>;
	const {response, loading, ...isoformProps} = Iceform.useResponse({
		res
	});

	const [responseData, setResponseData] = React.useState<unknown>();
	React.useEffect(() => {
		// response.bodyUsed might be undefined, so we use a strict comparison
		if (response?.bodyUsed === false) {
			response?.json().then((responseData) => {
				setResponseData(responseData);
			});
		}
	}, [response]);

	return (
		<Iceform.Form
			{...isoformProps}
			method="post"
			action={`/a/notes/${req.query.noteId}`}
			clientAction={`/api/notes/${req.query.noteId}`}
			clientMethod="put"
		>
			<div>
				<label>
					<span className="after:block">Title</span>
					<input type="text" name="title" defaultValue={body.title as string} />
				</label>
			</div>
			<div>
				<label>
					<span className="after:block">Image</span>
					<input type="file" name="image" />
				</label>
			</div>
			<div>
				<label>
					<span className="after:block">Content</span>
					<textarea name="content" defaultValue={body.content as string} />
				</label>
			</div>
			<div>
				<button type="submit">Submit</button>
			</div>
		</Iceform.Form>
	);
};

export const getServerSideProps = Iceform.destination.getServerSideProps({
	fn: async (actionReq, actionRes, ctx) => {
		const {noteId} = ctx.query;
		let origin: string;
		if (ctx.req.headers.referer) {
			const refererUrl = new URL(ctx.req.headers.referer as string);
			origin = refererUrl.origin;
		} else {
			// TODO how to get the scheme?
			const scheme = 'http';
			origin = `${scheme}://${ctx.req.headers.host}`;
		}
		const url = new URL(`/api/notes/${noteId}`, origin);
		const noteResponse = await fetch(url.toString(), {
			headers: {
				'Accept': 'application/json',
			}
		});
		if (noteResponse.ok) {
			const note = await noteResponse.json();
			return {
				props: {
					note,
				},
			};
		}

		return {
			notFound: true,
		};
	},
});

export default NotesItemPage;
